@@ -20,9 +20,11 @@
 #' @references Stan Development Team (2020). "RStan: the R interface to Stan." R package version 2.19.3, <https://mc-stan.org/>.
 #'
 #' @examples
+#' if (requireNamespace("rstan", quietly = TRUE)) {
 #' ivw_fit <- mr_ivw_stan(bmi_insulin)
 #' print(ivw_fit)
 #' rstan::traceplot(ivw_fit)
+#' }
 #' @export
 mr_ivw_stan <- function(data,
                         prior = 1,
@@ -32,6 +34,9 @@ mr_ivw_stan <- function(data,
                         seed = 12345,
                         ...) {
 
+  # check for rstan
+  rstan_check()
+
   # convert MRInput object to mr_format
   if ("MRInput" %in% class(data)) {
     data <- mrinput_mr_format(data)
